@@ -1,6 +1,6 @@
 
 gradients = [  # gradients which can be chosen when creating a video object later
-    ' `-~+\\!G@',
+    ' `-~+!G@',
     ' `\'"*+=g$@',
     ' ░▒▓█',
 ]
